@@ -5,10 +5,9 @@
 
 bark2hz <- function(z){
     
-    if(!is.numeric(z) || z < 0)
+    if(!is.numeric(z) || any(z < 0))
       stop("frequencies have to be non-negative")
 
     # Hynek's formula (taken from rasta/audspec.c)
     600 * sinh(z/6)
 }
-
